@@ -1,4 +1,4 @@
-###########################################################################/** 
+###########################################################################/**
 # @RdocFunction pseudoinverse
 #
 # @title "Calculates the pseudo inverse of a matrix"
@@ -13,7 +13,7 @@
 #  \item{X}{A @numeric @matrix.}
 #  \item{...}{Not used.}
 # }
-# 
+#
 # \value{
 #   Returns a @matrix.
 # }
@@ -28,7 +28,7 @@ pseudoinverse <- function(X, ...) {
   svd <- svd(X);
   d <- svd$d;
 
-  if(length(d) == 0) {
+  if(length(d) == 0L) {
     return(array(0, dim=dim(X)[2:1]));
   } else {
     return(svd$v %*% (1/d * t(svd$u)));
